using System;
using System.Collections.ObjectModel;
using LinqToSqlProvider.ObjectModel;
using Telerik.Windows.Controls.Scheduler;
using Telerik.Windows.Controls.Scheduler.ICalendar;

namespace LinqToSqlProvider
{
    internal class Data
    {
        private ObservableCollection<SqlAppointment> appointmentCollection;

        /// <summary>
        /// Gets sample appointments.
        /// </summary>
        /// <value>The appointments.</value>
        public ObservableCollection<SqlAppointment> Appointments
        {
            get
            {
                if (this.appointmentCollection == null)
                {
                    this.appointmentCollection = new ObservableCollection<SqlAppointment>();
                    DateTime mondayDate = CalendarHelper.GetFirstDayOfWeek(DateTime.Today, DayOfWeek.Monday);

                    var twoDayAppointment = new SqlAppointment();
                    twoDayAppointment.Subject = "Data access conference";
                    twoDayAppointment.Body = "Two day conference on the latest data access technologies in Boston.";
                    twoDayAppointment.Start = mondayDate.AddHours(10);
                    twoDayAppointment.End = mondayDate.Add(new TimeSpan(1, 17, 0, 0));

                    this.appointmentCollection.Add(twoDayAppointment);

                    DateTime meetingDay = mondayDate.AddDays(2);
                    var meetingAppointment = new SqlAppointment();
                    meetingAppointment.Subject = "Meeting with Mr. Smith";
                    meetingAppointment.Body = "On this meeting we need to discuss future business opportunities.";
                    meetingAppointment.Start = meetingDay.AddHours(9);
                    meetingAppointment.End = meetingDay.AddHours(9).AddMinutes(30);

                    this.appointmentCollection.Add(meetingAppointment);

                    var interviewAppointment = new SqlAppointment();
                    interviewAppointment.Subject = "Interview candidate for janitor";
                    interviewAppointment.Body =
                        "David Campbell is applying for janitor. His CV and references need to be reviewed before the interview.";
                    interviewAppointment.Start = meetingDay.AddHours(35);
                    interviewAppointment.End = meetingDay.AddHours(36);

                    this.appointmentCollection.Add(interviewAppointment);

                    var lunchAppointment = new SqlAppointment();
                    lunchAppointment.Subject = "Lunch with Lucy";
                    lunchAppointment.Body = "My sister Lucy is in town for a couple of days. We shall meet to catch up.";
                    lunchAppointment.Start = meetingDay.AddDays(7);
                    lunchAppointment.End = meetingDay.AddDays(7).AddHours(1);

                    this.appointmentCollection.Add(lunchAppointment);

                    var recurringAppointment = new SqlAppointment();
                    recurringAppointment.Subject = "Go to work";
                    recurringAppointment.Body = "I must go to work every week day.";
                    recurringAppointment.Start = mondayDate.AddDays(14).AddHours(8);
                    recurringAppointment.End = mondayDate.AddDays(14).AddHours(10);
                    
                    var recurrencePattern = new RecurrencePattern();
                    recurrencePattern.Frequency = RecurrenceFrequency.Daily;
                    recurrencePattern.Interval = 1;
                    recurrencePattern.MaxOccurrences = 5;
                    recurrencePattern.DaysOfWeekMask = RecurrenceDays.EveryDay;

                    recurringAppointment.RecurrenceRule = new RecurrenceRule(recurrencePattern);

                    this.appointmentCollection.Add(recurringAppointment);
                }

                return this.appointmentCollection;
            }
        }
    }
}