﻿using System.Windows;
using Telerik.Windows.Controls;

namespace LinqToSqlProvider.ObjectModel.Provider
{
    public static class ProviderManager
    {
        /// <summary>
        /// Identifies the <see cref="ProviderProperty"/>.
        /// </summary>
        public static readonly DependencyProperty ProviderProperty = DependencyProperty.RegisterAttached(
                "Provider", typeof (ISchedulerProvider), typeof (ProviderManager),
                new PropertyMetadata(null, OnProviderChanged));

        /// <summary>
        /// Gets the provider.
        /// </summary>
        /// <param name="obj">The obj.</param>
        /// <returns></returns>
        public static ISchedulerProvider GetProvider(DependencyObject obj)
        {
            return (ISchedulerProvider) obj.GetValue(ProviderProperty);
        }

        /// <summary>
        /// Sets the provider.
        /// </summary>
        /// <param name="obj">The obj.</param>
        /// <param name="value">The value.</param>
        public static void SetProvider(DependencyObject obj, ISchedulerProvider value)
        {
            obj.SetValue(ProviderProperty, value);
        }

        private static void OnProviderChanged(DependencyObject target, DependencyPropertyChangedEventArgs changedEventArgs)
        {
            var scheduler = target as RadScheduler;
            if (scheduler != null)
            {
                var oldSchedulerProvider = changedEventArgs.OldValue as ISchedulerProvider;
                if (oldSchedulerProvider != null)
                {
                    oldSchedulerProvider.Detach();
                }

                var newSchedulerProvider = changedEventArgs.NewValue as ISchedulerProvider;
                if (newSchedulerProvider != null)
                {
                    newSchedulerProvider.Attach(scheduler);
                }
            }
        }
    }
}